Callosum
========

Asynchronous multi-channel order-preserving RPC and data streaming library

*Corpus callosum* is a bundle of neuron fibers that connects two hemispheres of a human brain.

Features
--------

* Designed for Python asyncio and bases on ZeroMQ
* Client authentication and encrypted communication
* Persistent multiple messaging channels where each channel is order-preserved
* Intrinsic support for error propagation
* Supports large-size data streaming via automatic chunking

Installation
------------

TODO
